# Changes

## dev

* drop support for python < 3.8
* format and lint code with ruff
* convert to pyproject.toml
* os.system: update signature [breaking change]
* os.mkdir: update implementation
* commands: stop converting parsed `options` to dict [breaking change]

## 0.2.0

* commands: removed `no_color` option
* commands: corrected `run()` return value

## 0.1.1

* fix release version number

## 0.1.0

* initial release
